from ..types import BeforeRequestHook, BeforeRequestContext
import httpx
from typing import Union


class PrefixApiKeyHook(BeforeRequestHook):
    prefix = "Token"

    def before_request(
        self, hook_ctx: BeforeRequestContext, request: httpx.Request
    ) -> Union[httpx.Request, Exception]:
        existing_token: str = request.headers.get("Authorization")

        if existing_token.startswith(self.prefix):
            return request

        request.headers["Authorization"] = f"{self.prefix} {existing_token}"

        return request



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .apierror import APIError
    from .error import Error, ErrorData
    from .getpassageaudioop import (
        GetPassageAudioRequest,
        GetPassageAudioRequestTypedDict,
    )
    from .getpassagehtmlop import GetPassageHTMLRequest, GetPassageHTMLRequestTypedDict
    from .getpassagetextop import (
        GetPassageTextRequest,
        GetPassageTextRequestTypedDict,
        IndentUsing,
    )
    from .passagemeta import PassageMeta, PassageMetaTypedDict
    from .passageresponse import PassageResponse, PassageResponseTypedDict
    from .searchpassagesop import (
        Results,
        ResultsTypedDict,
        SearchPassagesRequest,
        SearchPassagesRequestTypedDict,
        SearchPassagesResponse,
        SearchPassagesResponseBody,
        SearchPassagesResponseBodyTypedDict,
        SearchPassagesResponseTypedDict,
        Verses,
        VersesTypedDict,
    )
    from .security import Security, SecurityTypedDict

__all__ = [
    "APIError",
    "Error",
    "ErrorData",
    "GetPassageAudioRequest",
    "GetPassageAudioRequestTypedDict",
    "GetPassageHTMLRequest",
    "GetPassageHTMLRequestTypedDict",
    "GetPassageTextRequest",
    "GetPassageTextRequestTypedDict",
    "IndentUsing",
    "PassageMeta",
    "PassageMetaTypedDict",
    "PassageResponse",
    "PassageResponseTypedDict",
    "Results",
    "ResultsTypedDict",
    "SearchPassagesRequest",
    "SearchPassagesRequestTypedDict",
    "SearchPassagesResponse",
    "SearchPassagesResponseBody",
    "SearchPassagesResponseBodyTypedDict",
    "SearchPassagesResponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "Verses",
    "VersesTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "APIError": ".apierror",
    "Error": ".error",
    "ErrorData": ".error",
    "GetPassageAudioRequest": ".getpassageaudioop",
    "GetPassageAudioRequestTypedDict": ".getpassageaudioop",
    "GetPassageHTMLRequest": ".getpassagehtmlop",
    "GetPassageHTMLRequestTypedDict": ".getpassagehtmlop",
    "GetPassageTextRequest": ".getpassagetextop",
    "GetPassageTextRequestTypedDict": ".getpassagetextop",
    "IndentUsing": ".getpassagetextop",
    "PassageMeta": ".passagemeta",
    "PassageMetaTypedDict": ".passagemeta",
    "PassageResponse": ".passageresponse",
    "PassageResponseTypedDict": ".passageresponse",
    "Results": ".searchpassagesop",
    "ResultsTypedDict": ".searchpassagesop",
    "SearchPassagesRequest": ".searchpassagesop",
    "SearchPassagesRequestTypedDict": ".searchpassagesop",
    "SearchPassagesResponse": ".searchpassagesop",
    "SearchPassagesResponseBody": ".searchpassagesop",
    "SearchPassagesResponseBodyTypedDict": ".searchpassagesop",
    "SearchPassagesResponseTypedDict": ".searchpassagesop",
    "Verses": ".searchpassagesop",
    "VersesTypedDict": ".searchpassagesop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from esv_sdk.types import BaseModel
from esv_sdk.utils import FieldMetadata, QueryParamMetadata
import pydantic
from typing import Callable, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SearchPassagesRequestTypedDict(TypedDict):
    query: str
    r"""The text to search for"""
    page_size: NotRequired[int]
    r"""Number of results to return per page"""
    page: NotRequired[int]
    r"""Page number to return"""


class SearchPassagesRequest(BaseModel):
    query: Annotated[
        str,
        pydantic.Field(alias="q"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
    r"""The text to search for"""

    page_size: Annotated[
        Optional[int],
        pydantic.Field(alias="page-size"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 20
    r"""Number of results to return per page"""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number to return"""


class VersesTypedDict(TypedDict):
    verse: NotRequired[str]
    r"""Verse reference"""
    text: NotRequired[str]
    r"""Verse text"""


class Verses(BaseModel):
    verse: Optional[str] = None
    r"""Verse reference"""

    text: Optional[str] = None
    r"""Verse text"""


class ResultsTypedDict(TypedDict):
    reference: NotRequired[str]
    r"""The passage reference"""
    content: NotRequired[str]
    r"""The matching passage content"""
    verses: NotRequired[List[VersesTypedDict]]


class Results(BaseModel):
    reference: Optional[str] = None
    r"""The passage reference"""

    content: Optional[str] = None
    r"""The matching passage content"""

    verses: Optional[List[Verses]] = None


class SearchPassagesResponseBodyTypedDict(TypedDict):
    r"""Successful response"""

    page: NotRequired[int]
    r"""Current page number"""
    total_pages: NotRequired[int]
    r"""Total number of pages"""
    total_results: NotRequired[int]
    r"""Total number of results"""
    results: NotRequired[List[ResultsTypedDict]]


class SearchPassagesResponseBody(BaseModel):
    r"""Successful response"""

    page: Optional[int] = None
    r"""Current page number"""

    total_pages: Optional[int] = None
    r"""Total number of pages"""

    total_results: Optional[int] = None
    r"""Total number of results"""

    results: Optional[List[Results]] = None


class SearchPassagesResponseTypedDict(TypedDict):
    result: SearchPassagesResponseBodyTypedDict


class SearchPassagesResponse(BaseModel):
    next: Callable[[], Optional[SearchPassagesResponse]]

    result: SearchPassagesResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from esv_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PassageMetaTypedDict(TypedDict):
    canonical: NotRequired[str]
    chapter_start: NotRequired[List[int]]
    chapter_end: NotRequired[List[int]]
    prev_verse: NotRequired[int]
    next_verse: NotRequired[int]
    prev_chapter: NotRequired[List[int]]
    next_chapter: NotRequired[List[int]]


class PassageMeta(BaseModel):
    canonical: Optional[str] = None

    chapter_start: Optional[List[int]] = None

    chapter_end: Optional[List[int]] = None

    prev_verse: Optional[int] = None

    next_verse: Optional[int] = None

    prev_chapter: Optional[List[int]] = None

    next_chapter: Optional[List[int]] = None
